@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.93
+# FitGallery 0.94
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -29,8 +29,7 @@ define('MAX_NUMBER',2000000000);
 function exit_error($texto)
 {
   header('Content-type: text/plain');
-  echo "FitGallery: $texto";
-  exit();
+  exit("FitGallery: $texto");
 }
 
 function invalid()
