@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.93
+# FitGallery 0.94
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -25,7 +25,8 @@ if ($dirgal=='' || $file=='') exit();
 
 $mtime=filemtime("$dirgal/$file");
 $handledir=opendir("$dirgal/$file/$dirimgs");
-$primero='x';
+$primero=NULL;
+$fecha_primero=PHP_INT_MAX;
 while (($fileimgs = readdir($handledir))!==false)
   {
     if ($fileimgs != '.' && $fileimgs != '..')
@@ -33,7 +34,8 @@ while (($fileimgs = readdir($handledir))!==false)
        $itemf="$dirgal/$file/$dirimgs/$fileimgs";
        if (is_readable($itemf))
        {
-         if ($primero == 'x') $primero=$fileimgs;
+         $fecha_actual=filemtime($itemf);
+         if ($fecha_actual<$fecha_primero || $primero===NULL) { $primero=$fileimgs; $fecha_primero=$fecha_actual; }
          $subtotal += filesize($itemf);
          $numimgs += 1;
        }
