@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.91
+# FitGallery 0.94
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -51,44 +51,48 @@ $subtotal=0;
 $numimgs=0;
 
 $handle=opendir($dirgal);         # Scan galeries directory
-while ($file = readdir($handle))
+while (($file = readdir($handle))!==false)
 { 
  if ($file != '.' && $file != '..')
   {
-    if (is_dir("$dirgal/$file"))
-     {
-       include 'scan_gal_dir.php';
+    $item="$dirgal/$file";
+    if (is_readable($item))
+    {
+      if (is_dir($item))
+       {
+         include 'scan_gal_dir.php';
 
-       $arr[$n]['file']=$file;
-       $arr[$n]['mtime']=date($date_string,$mtime);
-       $arr[$n]['subtotal']=$subtotal;
-       $subtotal=0;
-       $arr[$n]['numimgs']=$numimgs;
-       $numimgs=0;
-       $arr[$n]['primero']=$primero;
-     }
-    else
-     {
-       $arrfich=file("$dirgal/$file");
-       $arr[$n]['url_prefix']=rtrim($arrfich[0]).'/';
-       $arr[$n]['file']=rtrim($arrfich[1]);
-       if (($thumb_remoto=rtrim($arrfich[2])) == '')
-         {
-           $url_fich=file($arr[$n]['url_prefix'].'info_gal.php?valor='.$arr[$n]['file']);
-           $arr[$n]['mtime']=date($date_string,$url_fich[0]);
-           $arr[$n]['subtotal']=$url_fich[1];
-           $arr[$n]['numimgs']=$url_fich[2];
-           $arr[$n]['primero']=$url_fich[3];
-           $arr[$n]['titulo']=$url_fich[4];
-         }
-       else
-         {
-           $arr[$n]['primero']=$thumb_remoto;
-           $arr[$n]['titulo']=$arrfich[3];
-         }
-     }
-    $total += $arr[$n]['subtotal'];
-    $n++;
+         $arr[$n]['mtime']=date($date_string,$mtime);
+         $arr[$n]['file']=$file;
+         $arr[$n]['subtotal']=$subtotal;
+         $subtotal=0;
+         $arr[$n]['numimgs']=$numimgs;
+         $numimgs=0;
+         $arr[$n]['primero']=$primero;
+       }
+      else
+       {
+         $arrfich=file($item);
+         $arr[$n]['url_prefix']=rtrim($arrfich[0]).'/';
+         $arr[$n]['file']=rtrim($arrfich[1]);
+         if (($thumb_remoto=rtrim($arrfich[2])) == '')
+           {
+             $url_fich=file($arr[$n]['url_prefix'].'info_gal.php?valor='.$arr[$n]['file']);
+             $arr[$n]['mtime']=date($date_string,$url_fich[0]);
+             $arr[$n]['subtotal']=$url_fich[1];
+             $arr[$n]['numimgs']=$url_fich[2];
+             $arr[$n]['primero']=$url_fich[3];
+             $arr[$n]['titulo']=$url_fich[4];
+           }
+         else
+           {
+             $arr[$n]['primero']=$thumb_remoto;
+             $arr[$n]['titulo']=$arrfich[3];
+           }
+       }
+      $total += $arr[$n]['subtotal'];
+      $n++;
+    }
   }
 }
 closedir($handle); 
@@ -134,15 +138,13 @@ $siguiente=$para+$avance;
 
 html_begin($style,$titulo_texto,$titulo,$subtitulo,$desde,$hasta,$version,$charset,$lang);
 
-
           # Print top navigator
-if ($nav_pos=="top" || $nav_pos=="both")
+if ($nav_pos=='top' || $nav_pos=='both')
     out_nav($arrnav,$numer_pagmasuno,$text_pages,$anterior,
             $text_anterior,$siguiente,$text_siguiente,$numero_arch,$avance);
 
-
       # Print number-of-thumbnails-per-page form
-if ($tpp_pos=="top" || $tpp_pos=="both")
+if ($tpp_pos=='top' || $tpp_pos=='both')
     html_gapp_form($npages_user,$text_gapp,$avance,$text_change);
 
 html_sep();
@@ -157,25 +159,22 @@ for ( $i=$para ; $i <= $para2 ; $i++)
 
      $megas=round($arr[$i]['subtotal']/10485.76)/100;
 
-     html_image($arr[$i]['url_prefix'],$valor,$arr[$i]['primero'],$h_thumb,$i,
+     html_image($arr[$i]['url_prefix'],$valor,$arr[$i]['primero'],$i,
                 $titulo_galeria_texto,$arr[$i]['numimgs'],$text_images,
                 $arr[$i]['subtotal'],$megas,$arr[$i]['mtime'],$remote_espace);
-
    }
 
 html_sep();
 
       # Print bottom navigator
-if ($nav_pos=="bottom" || $nav_pos=="both")
+if ($nav_pos=='bottom' || $nav_pos=='both')
     out_nav($arrnav,$numer_pagmasuno,$text_pages,$anterior,
             $text_anterior,$siguiente,$text_siguiente,$numero_arch,$avance);
 
-
       # Print number-of-thumbnails-per-page form
-if ($tpp_pos=="bottom" || $tpp_pos=="both")
+if ($tpp_pos=='bottom' || $tpp_pos=='both')
     html_gapp_form($npages_user,$text_gapp,$avance,$text_change);
 
-
 html_end($text_totales,$total,$totalmegas,$powered,$text_powered,$version,$print_totals,$w3logo);
 
 
@@ -239,14 +238,16 @@ echo '</p>';
 }
 
 
-function html_image($url_prefix,$valor,$portada,$h_thumb,$i,$titulo_galeria_texto,
+function html_image($url_prefix,$valor,$portada,$i,$titulo_galeria_texto,
                     $size,$text_images,$bytes,$megas,$fecha,$remote_espace)
 {
    echo "
    <div class=\"figure\">
+   <p class=\"caption\">
    <a href=\"".$url_prefix."ver_thumb.php?galeria=$valor\">
-   <img class=\"thumbnail\" src=\"".$url_prefix."thumb.php?galeria=$valor&amp;valor=$portada&amp;altura=$h_thumb&amp;tipo=t\" alt=\"$valor\">
+   <img class=\"thumbnail\" src=\"".$url_prefix."thumb.php?galeria=$valor&amp;valor=$portada&amp;tipo=t\" alt=\"$valor\">
    </a>
+   </p>
    <p class=\"caption\">\n   ";
    echo $i+1;
    echo ". \n";
